@@ -1,5 +1,5 @@
 # Copyright (c) OpenMMLab. All rights reserved.
-from .attention import ShiftWindowMSA
+from .attention import MultiheadAttention, ShiftWindowMSA
 from .augment.augments import Augments
 from .channel_shuffle import channel_shuffle
 from .embed import HybridEmbed, PatchEmbed, PatchMerging
@@ -11,5 +11,6 @@ from .se_layer import SELayer
 __all__ = [
     'channel_shuffle', 'make_divisible', 'InvertedResidual', 'SELayer',
     'to_ntuple', 'to_2tuple', 'to_3tuple', 'to_4tuple', 'PatchEmbed',
-    'PatchMerging', 'HybridEmbed', 'Augments', 'ShiftWindowMSA', 'is_tracing'
+    'PatchMerging', 'HybridEmbed', 'Augments', 'ShiftWindowMSA', 'is_tracing',
+    'MultiheadAttention'
 ]
